@@ -1,7 +1,7 @@
 #' Remove/Replace/Extract Numbers
 #' 
-#' Remove/replace/extract number from a string (works on numbers with commas, 
-#' decimals and negatives).
+#' \code{rm_number} - Remove/replace/extract number from a string (works on 
+#' numbers with commas, decimals and negatives).
 #' 
 #' @param text.var The text variable.
 #' @param trim logical.  If \code{TRUE} removes leading and trailing white 
@@ -19,19 +19,55 @@
 #' @param dictionary A dictionary of canned regular expressions to search within 
 #' if \code{pattern} begins with \code{"@@rm_"}.
 #' @param \dots Other arguments passed to \code{\link[base]{gsub}}.
-#' @return Returns a character string with number removed.
+#' @return \code{rm_number} - Returns a character string with number removed.
 #' @keywords number
 #' @family rm_ functions
 #' @include utils.R
+#' @rdname rm_number
 #' @export
 #' @seealso \code{\link[base]{gsub}},
 #' \code{\link[stringi]{stri_extract_all_regex}}
-#' @references The number regular expression was taken from: 
-#' \url{http://stackoverflow.com/a/5917250/1000343} authored by Justin Morgan.
+#' @references The number regular expression was created by Jason Gray.
 #' @examples
 #' x <- c("-2 is an integer.  -4.3 and 3.33 are not.",
-#'     "123,456 is a lot more than -.2", 
-#'     "hello world -.q")
+#'     "123,456 is 0 alot -123456 more than -.2", "and 3456789123 fg for 345.",
+#'     "fg 12,345 23 .44 or 18.", "don't remove this 444,44", "hello world -.q")
+#' 
 #' rm_number(x)
 #' rm_number(x, extract=TRUE)
-rm_number <- hijack(rm_default, pattern = "@rm_number")
\ No newline at end of file
+#' 
+#' ##Convert to numeric
+#' as_numeric(rm_number(x, extract=TRUE))   # retain list
+#' as_numeric2(rm_number(x, extract=TRUE))  # unlist
+rm_number <- hijack(rm_default, pattern = "@rm_number")
+
+
+#' Remove/Replace/Extract Numbers
+#' 
+#' \code{as_numeric} - A wrapper for \code{as.numeric(gsub(",", "", x))}, which
+#' removes commas and converts a list of vectors of strings to numeric.  If the 
+#' string cannot be converted to numeric \code{NA} is returned.
+#' 
+#' @param x a character vector to convert to a numeric vector.
+#' @rdname rm_number
+#' @return \code{as_numeric2} - Returns a list of vectors of numbers.
+#' @export
+as_numeric <- function(x) {
+    lapply(x, function(y){
+        as.numeric(gsub(",", "", y))
+    })
+}
+
+#' Remove/Replace/Extract Numbers
+#' 
+#' \code{as_numeric2} - A convenience function for \code{as_numeric} that 
+#' unlists and returns a vector rather than a list.
+#' 
+#' @rdname rm_number
+#' @export
+#' @return \code{as_numeric2} - Returns a vector of numbers.
+as_numeric2 <- function(x) {
+    unlist(as_numeric(x))
+}
+
+
