@@ -111,14 +111,24 @@ examine_regex <- function(dictionary = qdapRegex::regex_usa){
     lapply(seq_along(dictionary), function(i){
         message(sprintf("\nHere's the regex for `%s`:\n\n  %s", names(dictionary)[i], 
             dictionary[[i]]), "\n\nDo you want to view it?")
-        ans <- menu(c("Yes", "No"))
+        ans <- utils::menu(c("Yes", "No"))
         if (ans == "2") return(NULL) 
         open <- TRUE
         if (grepl("\\(\\?\\<[=!]", dictionary[[i]], perl=TRUE)) {
             warning(immediate. = TRUE, paste("Pattern contains a Lookbehind and is not",
                 "viewable to the Java based `www.regexper.com`\n\n", "Setting `open = FALSE`"))
-            flush.console(); Sys.sleep(1); open <- FALSE
+            utils::flush.console(); Sys.sleep(1); open <- FALSE
         } 
         explain(dictionary[[i]], open=open)
     })
 }
+
+## Make ist into extracted class
+ext <- function(x){
+    if(!any(class(x) %in% "list")) return(x)
+    class(x) <- c("extracted", class(x)) 
+    x
+}
+
+
+
